You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@flex.apache.org by cf...@apache.org on 2012/05/29 19:11:06 UTC

svn commit: r1343856 [3/4] - in /incubator/flex/trunk/modules: compiler/ compiler/src/java/flex2/compiler/as3/binding/ compiler/src/java/flex2/compiler/as3/genext/ compiler/src/java/flex2/compiler/css/ compiler/src/java/flex2/compiler/media/ compiler/s...

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTComment.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTComment.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTComment.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTComment.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2002,2004 The Apache Software Foundation.
@@ -20,12 +20,12 @@ package org.apache.velocity.runtime.pars
  *  Modified by Adobe Flex.
  */
 
-import org.apache.velocity.runtime.parser.Parser;
-import org.apache.velocity.runtime.parser.Token;
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.exception.ResourceNotFoundException;
-import org.apache.velocity.exception.ParseErrorException;
-import org.apache.velocity.exception.MethodInvocationException;
+import org.apache.flex.forks.velocity.runtime.parser.Parser;
+import org.apache.flex.forks.velocity.runtime.parser.Token;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.exception.ResourceNotFoundException;
+import org.apache.flex.forks.velocity.exception.ParseErrorException;
+import org.apache.flex.forks.velocity.exception.MethodInvocationException;
 
 import java.io.IOException;
 import java.io.Writer;

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTDirective.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTDirective.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTDirective.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTDirective.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -23,13 +23,13 @@ package org.apache.velocity.runtime.pars
 import java.io.Writer;
 import java.io.IOException;
 
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.runtime.directive.Directive;
-import org.apache.velocity.runtime.parser.Parser;
-
-import org.apache.velocity.exception.MethodInvocationException;
-import org.apache.velocity.exception.ParseErrorException;
-import org.apache.velocity.exception.ResourceNotFoundException;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.runtime.directive.Directive;
+import org.apache.flex.forks.velocity.runtime.parser.Parser;
+
+import org.apache.flex.forks.velocity.exception.MethodInvocationException;
+import org.apache.flex.forks.velocity.exception.ParseErrorException;
+import org.apache.flex.forks.velocity.exception.ResourceNotFoundException;
 
 /**
  * This class is responsible for handling the pluggable

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTDivNode.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTDivNode.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTDivNode.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTDivNode.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -16,10 +16,10 @@ package org.apache.velocity.runtime.pars
  * limitations under the License.
  */
 
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.runtime.parser.Parser;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.runtime.parser.Parser;
 
-import org.apache.velocity.exception.MethodInvocationException;
+import org.apache.flex.forks.velocity.exception.MethodInvocationException;
 
 /**
  * Handles integer division of nodes

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTEQNode.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTEQNode.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTEQNode.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTEQNode.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -16,10 +16,10 @@ package org.apache.velocity.runtime.pars
  * limitations under the License.
  */
 
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.runtime.parser.Parser;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.runtime.parser.Parser;
 
-import org.apache.velocity.exception.MethodInvocationException;
+import org.apache.flex.forks.velocity.exception.MethodInvocationException;
 
 /**
  *  Handles the equivalence operator

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTElseIfStatement.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTElseIfStatement.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTElseIfStatement.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTElseIfStatement.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -19,12 +19,12 @@ package org.apache.velocity.runtime.pars
 import java.io.Writer;
 import java.io.IOException;
 
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.runtime.parser.*;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.runtime.parser.*;
 
-import org.apache.velocity.exception.MethodInvocationException;
-import org.apache.velocity.exception.ParseErrorException;
-import org.apache.velocity.exception.ResourceNotFoundException;
+import org.apache.flex.forks.velocity.exception.MethodInvocationException;
+import org.apache.flex.forks.velocity.exception.ParseErrorException;
+import org.apache.flex.forks.velocity.exception.ResourceNotFoundException;
 
 /**
  * This class is responsible for handling the ElseIf VTL control statement.

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTElseStatement.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTElseStatement.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTElseStatement.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTElseStatement.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -16,8 +16,8 @@ package org.apache.velocity.runtime.pars
  * limitations under the License.
  */
 
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.runtime.parser.Parser;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.runtime.parser.Parser;
 
 /**
  * This class is responsible for handling the Else VTL control statement.

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTEscape.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTEscape.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTEscape.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTEscape.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -23,8 +23,8 @@ package org.apache.velocity.runtime.pars
 import java.io.Writer;
 import java.io.IOException;
 
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.runtime.parser.Parser;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.runtime.parser.Parser;
 
 /**
  * This class is responsible for handling Escapes

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTEscapedDirective.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTEscapedDirective.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTEscapedDirective.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTEscapedDirective.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -23,8 +23,8 @@ package org.apache.velocity.runtime.pars
 import java.io.Writer;
 import java.io.IOException;
 
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.runtime.parser.Parser;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.runtime.parser.Parser;
 
 /**
  * This class is responsible for handling EscapedDirectives

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTExpression.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTExpression.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTExpression.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTExpression.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -16,10 +16,10 @@ package org.apache.velocity.runtime.pars
  * limitations under the License.
  */
 
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.runtime.parser.Parser;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.runtime.parser.Parser;
 
-import org.apache.velocity.exception.MethodInvocationException;
+import org.apache.flex.forks.velocity.exception.MethodInvocationException;
 
 public class ASTExpression extends SimpleNode
 {

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTFalse.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTFalse.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTFalse.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTFalse.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -17,8 +17,8 @@ package org.apache.velocity.runtime.pars
  */
 
 
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.runtime.parser.Parser;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.runtime.parser.Parser;
 
 public class ASTFalse extends SimpleNode
 {

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTGENode.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTGENode.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTGENode.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTGENode.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -16,9 +16,9 @@ package org.apache.velocity.runtime.pars
  * limitations under the License.
  */
 
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.runtime.parser.Parser;
-import org.apache.velocity.exception.MethodInvocationException;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.runtime.parser.Parser;
+import org.apache.flex.forks.velocity.exception.MethodInvocationException;
 
 public class ASTGENode extends SimpleNode
 {

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTGTNode.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTGTNode.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTGTNode.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTGTNode.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -16,9 +16,9 @@ package org.apache.velocity.runtime.pars
  * limitations under the License.
  */
 
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.runtime.parser.Parser;
-import org.apache.velocity.exception.MethodInvocationException;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.runtime.parser.Parser;
+import org.apache.flex.forks.velocity.exception.MethodInvocationException;
 
 
 public class ASTGTNode extends SimpleNode

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTIdentifier.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTIdentifier.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTIdentifier.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTIdentifier.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2002,2004 The Apache Software Foundation.
@@ -20,14 +20,14 @@ package org.apache.velocity.runtime.pars
  *  Modified by Adobe Flex.
  */
 
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.runtime.parser.Parser;
-import org.apache.velocity.util.introspection.IntrospectionCacheData;
-import org.apache.velocity.util.introspection.Info;
-import org.apache.velocity.util.introspection.VelPropertyGet;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.runtime.parser.Parser;
+import org.apache.flex.forks.velocity.util.introspection.IntrospectionCacheData;
+import org.apache.flex.forks.velocity.util.introspection.Info;
+import org.apache.flex.forks.velocity.util.introspection.VelPropertyGet;
 
-import org.apache.velocity.exception.MethodInvocationException;
-import org.apache.velocity.app.event.EventCartridge;
+import org.apache.flex.forks.velocity.exception.MethodInvocationException;
+import org.apache.flex.forks.velocity.app.event.EventCartridge;
 
 import java.lang.reflect.InvocationTargetException;
 

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTIfStatement.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTIfStatement.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTIfStatement.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTIfStatement.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -30,12 +30,12 @@ package org.apache.velocity.runtime.pars
 import java.io.Writer;
 import java.io.IOException;
 
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.runtime.parser.*;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.runtime.parser.*;
 
-import org.apache.velocity.exception.MethodInvocationException;
-import org.apache.velocity.exception.ParseErrorException;
-import org.apache.velocity.exception.ResourceNotFoundException;
+import org.apache.flex.forks.velocity.exception.MethodInvocationException;
+import org.apache.flex.forks.velocity.exception.ParseErrorException;
+import org.apache.flex.forks.velocity.exception.ResourceNotFoundException;
 
 
 public class ASTIfStatement extends SimpleNode

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTIncludeStatement.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTIncludeStatement.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTIncludeStatement.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTIncludeStatement.java Tue May 29 17:10:53 2012
@@ -1,8 +1,8 @@
 /* Generated By:JJTree: Do not edit this line. ASTIncludeStatement.java */
 
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
-import org.apache.velocity.runtime.parser.*;
+import org.apache.flex.forks.velocity.runtime.parser.*;
 
 public class ASTIncludeStatement extends SimpleNode
 {

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTIntegerRange.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTIntegerRange.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTIntegerRange.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTIntegerRange.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -29,10 +29,10 @@ package org.apache.velocity.runtime.pars
 
 import java.util.ArrayList;
 
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.runtime.parser.Parser;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.runtime.parser.Parser;
 
-import org.apache.velocity.exception.MethodInvocationException;
+import org.apache.flex.forks.velocity.exception.MethodInvocationException;
 
 public class ASTIntegerRange extends SimpleNode {
   

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTLENode.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTLENode.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTLENode.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTLENode.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -16,10 +16,10 @@ package org.apache.velocity.runtime.pars
  * limitations under the License.
  */
 
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.runtime.parser.Parser;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.runtime.parser.Parser;
 
-import org.apache.velocity.exception.MethodInvocationException;
+import org.apache.flex.forks.velocity.exception.MethodInvocationException;
 
 public class ASTLENode extends SimpleNode
 {

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTLTNode.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTLTNode.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTLTNode.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTLTNode.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -16,10 +16,10 @@ package org.apache.velocity.runtime.pars
  * limitations under the License.
  */
 
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.runtime.parser.Parser;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.runtime.parser.Parser;
 
-import org.apache.velocity.exception.MethodInvocationException;
+import org.apache.flex.forks.velocity.exception.MethodInvocationException;
 
 public class ASTLTNode extends SimpleNode
 {

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTMethod.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTMethod.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTMethod.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTMethod.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -20,16 +20,16 @@ package org.apache.velocity.runtime.pars
  *  Modified by Adobe Flex.
  */
 
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.runtime.parser.*;
-import org.apache.velocity.util.introspection.IntrospectionCacheData;
-import org.apache.velocity.util.introspection.VelMethod;
-import org.apache.velocity.util.introspection.Info;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.runtime.parser.*;
+import org.apache.flex.forks.velocity.util.introspection.IntrospectionCacheData;
+import org.apache.flex.forks.velocity.util.introspection.VelMethod;
+import org.apache.flex.forks.velocity.util.introspection.Info;
 
-import org.apache.velocity.exception.MethodInvocationException;
+import org.apache.flex.forks.velocity.exception.MethodInvocationException;
 import java.lang.reflect.InvocationTargetException;
 
-import org.apache.velocity.app.event.EventCartridge;
+import org.apache.flex.forks.velocity.app.event.EventCartridge;
 
 /**
  *  ASTMethod.java

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTModNode.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTModNode.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTModNode.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTModNode.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -26,10 +26,10 @@ package org.apache.velocity.runtime.pars
  * @author <a href="mailto:geirm@optonline.net">Geir Magnusson Jr.</a>
  * @version $Id: ASTModNode.java,v 1.6.10.1 2004/03/03 23:22:59 geirm Exp $ 
 */
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.runtime.parser.Parser;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.runtime.parser.Parser;
 
-import org.apache.velocity.exception.MethodInvocationException;
+import org.apache.flex.forks.velocity.exception.MethodInvocationException;
 
 public class ASTModNode extends SimpleNode
 {

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTMulNode.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTMulNode.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTMulNode.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTMulNode.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -16,10 +16,10 @@ package org.apache.velocity.runtime.pars
  * limitations under the License.
  */
 
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.runtime.parser.Parser;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.runtime.parser.Parser;
 
-import org.apache.velocity.exception.MethodInvocationException;
+import org.apache.flex.forks.velocity.exception.MethodInvocationException;
 
 /**
  * Handles integer multiplication

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTNENode.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTNENode.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTNENode.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTNENode.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -16,10 +16,10 @@ package org.apache.velocity.runtime.pars
  * limitations under the License.
  */
 
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.runtime.parser.Parser;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.runtime.parser.Parser;
 
-import org.apache.velocity.exception.MethodInvocationException;
+import org.apache.flex.forks.velocity.exception.MethodInvocationException;
 
 public class ASTNENode extends SimpleNode
 {

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTNotNode.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTNotNode.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTNotNode.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTNotNode.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -16,10 +16,10 @@ package org.apache.velocity.runtime.pars
  * limitations under the License.
  */
 
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.runtime.parser.*;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.runtime.parser.*;
 
-import org.apache.velocity.exception.MethodInvocationException;
+import org.apache.flex.forks.velocity.exception.MethodInvocationException;
 
 public class ASTNotNode extends SimpleNode
 {

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTNumberLiteral.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTNumberLiteral.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTNumberLiteral.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTNumberLiteral.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -20,8 +20,8 @@ package org.apache.velocity.runtime.pars
  *  Modified by Adobe Flex.
  */
 
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.runtime.parser.Parser;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.runtime.parser.Parser;
 
 public class ASTNumberLiteral extends SimpleNode
 {

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTObjectArray.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTObjectArray.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTObjectArray.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTObjectArray.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -18,10 +18,10 @@ package org.apache.velocity.runtime.pars
 
 import java.util.ArrayList;
 
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.runtime.parser.Parser;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.runtime.parser.Parser;
 
-import org.apache.velocity.exception.MethodInvocationException;
+import org.apache.flex.forks.velocity.exception.MethodInvocationException;
 
 public class ASTObjectArray extends SimpleNode
 {

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTOrNode.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTOrNode.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTOrNode.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTOrNode.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -16,10 +16,10 @@ package org.apache.velocity.runtime.pars
  * limitations under the License.
  */
 
-import org.apache.velocity.runtime.parser.Parser;
-import org.apache.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.runtime.parser.Parser;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
 
-import org.apache.velocity.exception.MethodInvocationException;
+import org.apache.flex.forks.velocity.exception.MethodInvocationException;
 
 /**
  * Please look at the Parser.jjt file which is

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTParameters.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTParameters.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTParameters.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTParameters.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -16,7 +16,7 @@ package org.apache.velocity.runtime.pars
  * limitations under the License.
  */
 
-import org.apache.velocity.runtime.parser.Parser;
+import org.apache.flex.forks.velocity.runtime.parser.Parser;
 
 public class ASTParameters extends SimpleNode
 {

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTReference.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTReference.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTReference.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTReference.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2002,2004 The Apache Software Foundation.
@@ -24,18 +24,18 @@ import java.io.Writer;
 import java.io.IOException;
 import java.lang.reflect.InvocationTargetException;
 
-import org.apache.velocity.context.Context;
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.runtime.RuntimeConstants;
-import org.apache.velocity.runtime.exception.ReferenceException;
-import org.apache.velocity.runtime.parser.*;
+import org.apache.flex.forks.velocity.context.Context;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.runtime.RuntimeConstants;
+import org.apache.flex.forks.velocity.runtime.exception.ReferenceException;
+import org.apache.flex.forks.velocity.runtime.parser.*;
 
-import org.apache.velocity.util.introspection.VelPropertySet;
-import org.apache.velocity.util.introspection.Info;
+import org.apache.flex.forks.velocity.util.introspection.VelPropertySet;
+import org.apache.flex.forks.velocity.util.introspection.Info;
 
-import org.apache.velocity.exception.MethodInvocationException;
+import org.apache.flex.forks.velocity.exception.MethodInvocationException;
 
-import org.apache.velocity.app.event.EventCartridge;
+import org.apache.flex.forks.velocity.app.event.EventCartridge;
 
 /**
  * This class is responsible for handling the references in

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTSetDirective.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTSetDirective.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTSetDirective.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTSetDirective.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -23,13 +23,13 @@ package org.apache.velocity.runtime.pars
 import java.io.IOException;
 import java.io.Writer;
 
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.runtime.RuntimeConstants;
-import org.apache.velocity.runtime.parser.Parser;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.runtime.RuntimeConstants;
+import org.apache.flex.forks.velocity.runtime.parser.Parser;
 
-import org.apache.velocity.exception.MethodInvocationException;
+import org.apache.flex.forks.velocity.exception.MethodInvocationException;
 
-import org.apache.velocity.app.event.EventCartridge;
+import org.apache.flex.forks.velocity.app.event.EventCartridge;
 
 /**
  * Node for the #set directive

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTStringLiteral.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTStringLiteral.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTStringLiteral.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTStringLiteral.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -20,16 +20,16 @@ package org.apache.velocity.runtime.pars
  *  Modified by Adobe Flex.
  */
 
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.runtime.parser.ParseException;
-import org.apache.velocity.runtime.parser.Parser;
-import org.apache.velocity.runtime.parser.Token;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.runtime.parser.ParseException;
+import org.apache.flex.forks.velocity.runtime.parser.Parser;
+import org.apache.flex.forks.velocity.runtime.parser.Token;
 
 import java.io.StringWriter;
 import java.io.BufferedReader;
 import java.io.StringReader;
 
-import org.apache.velocity.runtime.RuntimeConstants;
+import org.apache.flex.forks.velocity.runtime.RuntimeConstants;
 
 /**
  * ASTStringLiteral support.  Will interpolate!

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTSubtractNode.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTSubtractNode.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTSubtractNode.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTSubtractNode.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -16,10 +16,10 @@ package org.apache.velocity.runtime.pars
  * limitations under the License.
  */
 
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.runtime.parser.Parser;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.runtime.parser.Parser;
 
-import org.apache.velocity.exception.MethodInvocationException;
+import org.apache.flex.forks.velocity.exception.MethodInvocationException;
 
 /**
  * Handles integer subtraction of nodes (in #set() )

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTText.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTText.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTText.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTText.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -23,9 +23,9 @@ package org.apache.velocity.runtime.pars
 import java.io.Writer;
 import java.io.IOException;
 
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.runtime.parser.Parser;
-import org.apache.velocity.runtime.parser.Token;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.runtime.parser.Parser;
+import org.apache.flex.forks.velocity.runtime.parser.Token;
 
 public class ASTText extends SimpleNode
 {

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTTrue.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTTrue.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTTrue.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTTrue.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -16,8 +16,8 @@ package org.apache.velocity.runtime.pars
  * limitations under the License.
  */
 
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.runtime.parser.Parser;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.runtime.parser.Parser;
 
 public class ASTTrue extends SimpleNode
 {

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTVariable.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTVariable.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTVariable.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTVariable.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -16,7 +16,7 @@ package org.apache.velocity.runtime.pars
  * limitations under the License.
  */
 
-import org.apache.velocity.runtime.parser.Parser;
+import org.apache.flex.forks.velocity.runtime.parser.Parser;
 
 public class ASTVariable extends SimpleNode
 {

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTWord.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTWord.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTWord.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTWord.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -20,7 +20,7 @@ package org.apache.velocity.runtime.pars
  *  Modified by Adobe Flex.
  */
 
-import org.apache.velocity.runtime.parser.Parser;
+import org.apache.flex.forks.velocity.runtime.parser.Parser;
 
 public class ASTWord extends SimpleNode {
 	public ASTWord(int id) {

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTprocess.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTprocess.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTprocess.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ASTprocess.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -16,7 +16,7 @@ package org.apache.velocity.runtime.pars
  * limitations under the License.
  */
 
-import org.apache.velocity.runtime.parser.Parser;
+import org.apache.flex.forks.velocity.runtime.parser.Parser;
 
 public class ASTprocess extends SimpleNode
 {

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/AbstractExecutor.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/AbstractExecutor.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/AbstractExecutor.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/AbstractExecutor.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -20,7 +20,7 @@ package org.apache.velocity.runtime.pars
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
 
-import org.apache.velocity.runtime.RuntimeLogger;
+import org.apache.flex.forks.velocity.runtime.RuntimeLogger;
 
 /**
  * Abstract class that is used to execute an arbitrary

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/BooleanPropertyExecutor.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/BooleanPropertyExecutor.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/BooleanPropertyExecutor.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/BooleanPropertyExecutor.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
  * 
@@ -15,9 +15,9 @@ package org.apache.velocity.runtime.pars
  * limitations under the License.
  */
 
-import org.apache.velocity.util.introspection.Introspector;
+import org.apache.flex.forks.velocity.util.introspection.Introspector;
 
-import org.apache.velocity.runtime.RuntimeLogger;
+import org.apache.flex.forks.velocity.runtime.RuntimeLogger;
 
 /**
  *  Handles discovery and valuation of a

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/GetExecutor.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/GetExecutor.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/GetExecutor.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/GetExecutor.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
  * 
@@ -15,13 +15,13 @@ package org.apache.velocity.runtime.pars
  * limitations under the License.
  */
 
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.util.introspection.Introspector;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.util.introspection.Introspector;
 
 import java.lang.reflect.InvocationTargetException;
-import org.apache.velocity.exception.MethodInvocationException;
+import org.apache.flex.forks.velocity.exception.MethodInvocationException;
 
-import org.apache.velocity.runtime.RuntimeLogger;
+import org.apache.flex.forks.velocity.runtime.RuntimeLogger;
 
 
 /**

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/Node.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/Node.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/Node.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/Node.java Tue May 29 17:10:53 2012
@@ -18,18 +18,18 @@
  *  Modified by Adobe Flex.
  */
 
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 import java.io.Serializable;
 import java.io.Writer;
 import java.io.IOException;
 
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.runtime.parser.Token;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.runtime.parser.Token;
 
-import org.apache.velocity.exception.MethodInvocationException;
-import org.apache.velocity.exception.ParseErrorException;
-import org.apache.velocity.exception.ResourceNotFoundException;
+import org.apache.flex.forks.velocity.exception.MethodInvocationException;
+import org.apache.flex.forks.velocity.exception.ParseErrorException;
+import org.apache.flex.forks.velocity.exception.ResourceNotFoundException;
 
 /**
  *  All AST nodes must implement this interface.  It provides basic

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/NodeUtils.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/NodeUtils.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/NodeUtils.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/NodeUtils.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
  * 
@@ -15,8 +15,8 @@ package org.apache.velocity.runtime.pars
  * limitations under the License.
  */
 
-import org.apache.velocity.context.Context;
-import org.apache.velocity.runtime.parser.*;
+import org.apache.flex.forks.velocity.context.Context;
+import org.apache.flex.forks.velocity.runtime.parser.*;
 
 /**
  * Utilities for dealing with the AST node structure.

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ParserVisitor.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ParserVisitor.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ParserVisitor.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/ParserVisitor.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/PropertyExecutor.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/PropertyExecutor.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/PropertyExecutor.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/PropertyExecutor.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 /*
  * Copyright 2000-2002,2004 The Apache Software Foundation.
  * 
@@ -17,9 +17,9 @@ package org.apache.velocity.runtime.pars
 
 import java.lang.reflect.InvocationTargetException;
 
-import org.apache.velocity.util.introspection.Introspector;
+import org.apache.flex.forks.velocity.util.introspection.Introspector;
 
-import org.apache.velocity.runtime.RuntimeLogger;
+import org.apache.flex.forks.velocity.runtime.RuntimeLogger;
 
 /**
  * Returned the value of object property when executed.

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/SimpleNode.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/SimpleNode.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/SimpleNode.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/parser/node/SimpleNode.java Tue May 29 17:10:53 2012
@@ -18,20 +18,20 @@
  *  Modified by Adobe Flex.
  */
 
-package org.apache.velocity.runtime.parser.node;
+package org.apache.flex.forks.velocity.runtime.parser.node;
 
 import java.io.Writer;
 import java.io.IOException;
 
-import org.apache.velocity.context.InternalContextAdapter;
-import org.apache.velocity.runtime.RuntimeServices;
-import org.apache.velocity.runtime.exception.ReferenceException;
-import org.apache.velocity.runtime.parser.Parser;
-import org.apache.velocity.runtime.parser.Token;
-
-import org.apache.velocity.exception.MethodInvocationException;
-import org.apache.velocity.exception.ParseErrorException;
-import org.apache.velocity.exception.ResourceNotFoundException;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.runtime.RuntimeServices;
+import org.apache.flex.forks.velocity.runtime.exception.ReferenceException;
+import org.apache.flex.forks.velocity.runtime.parser.Parser;
+import org.apache.flex.forks.velocity.runtime.parser.Token;
+
+import org.apache.flex.forks.velocity.exception.MethodInvocationException;
+import org.apache.flex.forks.velocity.exception.ParseErrorException;
+import org.apache.flex.forks.velocity.exception.ResourceNotFoundException;
 
 
 public class SimpleNode implements Node

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/ContentResource.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/ContentResource.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/ContentResource.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/ContentResource.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.resource;
+package org.apache.flex.forks.velocity.runtime.resource;
 
 /*
  * Copyright 2001,2004 The Apache Software Foundation.
@@ -20,13 +20,13 @@ import java.io.StringWriter;
 import java.io.BufferedReader;
 import java.io.InputStreamReader;
 
-import org.apache.velocity.exception.ResourceNotFoundException;
+import org.apache.flex.forks.velocity.exception.ResourceNotFoundException;
 
 /**
  * This class represent a general text resource that may have been
  * retrieved from any number of possible sources.
  *
- * Also of interest is Velocity's {@link org.apache.velocity.Template}
+ * Also of interest is Velocity's {@link org.apache.flex.forks.velocity.Template}
  * <code>Resource</code>.
  *
  * @author <a href="mailto:jvanzyl@apache.org">Jason van Zyl</a>

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/Resource.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/Resource.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/ResourceCache.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/ResourceCache.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.resource;
+package org.apache.flex.forks.velocity.runtime.resource;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -17,7 +17,7 @@ package org.apache.velocity.runtime.reso
  */
 
 import java.util.Iterator;
-import org.apache.velocity.runtime.RuntimeServices;
+import org.apache.flex.forks.velocity.runtime.RuntimeServices;
 
 /**
  * Interface that defines the shape of a pluggable resource cache

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/ResourceCacheImpl.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/ResourceCacheImpl.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/ResourceCacheImpl.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/ResourceCacheImpl.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.resource;
+package org.apache.flex.forks.velocity.runtime.resource;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -19,7 +19,7 @@ package org.apache.velocity.runtime.reso
 import java.util.Hashtable;
 import java.util.Map;
 import java.util.Iterator;
-import org.apache.velocity.runtime.RuntimeServices;
+import org.apache.flex.forks.velocity.runtime.RuntimeServices;
 
 /**
  * Default implementation of the resource cache for the default

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/ResourceFactory.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/ResourceFactory.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/ResourceFactory.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/ResourceFactory.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.resource;
+package org.apache.flex.forks.velocity.runtime.resource;
 
 /*
  * Copyright 2001,2004 The Apache Software Foundation.
@@ -16,7 +16,7 @@ package org.apache.velocity.runtime.reso
  * limitations under the License.
  */
 
-import org.apache.velocity.Template;
+import org.apache.flex.forks.velocity.Template;
 
 /**
  * Class responsible for instantiating <code>Resource</code> objects,

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/ResourceManager.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/ResourceManager.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/ResourceManager.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/ResourceManager.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.resource;
+package org.apache.flex.forks.velocity.runtime.resource;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -16,10 +16,10 @@ package org.apache.velocity.runtime.reso
  * limitations under the License.
  */
 
-import org.apache.velocity.runtime.RuntimeServices;
+import org.apache.flex.forks.velocity.runtime.RuntimeServices;
 
-import org.apache.velocity.exception.ResourceNotFoundException;
-import org.apache.velocity.exception.ParseErrorException;
+import org.apache.flex.forks.velocity.exception.ResourceNotFoundException;
+import org.apache.flex.forks.velocity.exception.ParseErrorException;
 
 /**
  * Class to manage the text resource for the Velocity

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/ResourceManagerImpl.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/ResourceManagerImpl.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/ResourceManagerImpl.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/ResourceManagerImpl.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.resource;
+package org.apache.flex.forks.velocity.runtime.resource;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -23,15 +23,15 @@ import java.util.Vector;
 import java.io.InputStream;
 import java.io.IOException;
 
-import org.apache.velocity.runtime.RuntimeServices;
-import org.apache.velocity.runtime.RuntimeConstants;
+import org.apache.flex.forks.velocity.runtime.RuntimeServices;
+import org.apache.flex.forks.velocity.runtime.RuntimeConstants;
 
-import org.apache.velocity.runtime.resource.ResourceFactory;
-import org.apache.velocity.runtime.resource.loader.ResourceLoader;
-import org.apache.velocity.runtime.resource.loader.ResourceLoaderFactory;
+import org.apache.flex.forks.velocity.runtime.resource.ResourceFactory;
+import org.apache.flex.forks.velocity.runtime.resource.loader.ResourceLoader;
+import org.apache.flex.forks.velocity.runtime.resource.loader.ResourceLoaderFactory;
 
-import org.apache.velocity.exception.ResourceNotFoundException;
-import org.apache.velocity.exception.ParseErrorException;
+import org.apache.flex.forks.velocity.exception.ResourceNotFoundException;
+import org.apache.flex.forks.velocity.exception.ParseErrorException;
 
 import org.apache.commons.collections.ExtendedProperties;
 

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/loader/ClasspathResourceLoader.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/loader/ClasspathResourceLoader.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/loader/ClasspathResourceLoader.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/loader/ClasspathResourceLoader.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.resource.loader;
+package org.apache.flex.forks.velocity.runtime.resource.loader;
 
 /*
  * Copyright 2001,2004 The Apache Software Foundation.
@@ -18,8 +18,8 @@ package org.apache.velocity.runtime.reso
  
 import java.io.InputStream;
 
-import org.apache.velocity.runtime.resource.Resource;
-import org.apache.velocity.exception.ResourceNotFoundException;
+import org.apache.flex.forks.velocity.runtime.resource.Resource;
+import org.apache.flex.forks.velocity.exception.ResourceNotFoundException;
 
 import org.apache.commons.collections.ExtendedProperties;
 
@@ -43,7 +43,7 @@ import org.apache.commons.collections.Ex
  *  <br>
  *  resource.loader = class
  *  class.resource.loader.class =
- *    org.apache.velocity.runtime.resource.loader.ClasspathResourceLoader
+ *    org.apache.flex.forks.velocity.runtime.resource.loader.ClasspathResourceLoader
  *  <br>
  *  <br>
  *  To use, put your template directories, jars

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/loader/DataSourceResourceLoader.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/loader/DataSourceResourceLoader.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/loader/DataSourceResourceLoader.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/loader/DataSourceResourceLoader.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.resource.loader;
+package org.apache.flex.forks.velocity.runtime.resource.loader;
 
 /*
  * Copyright 2001-2002,2004 The Apache Software Foundation.
@@ -23,10 +23,10 @@ import java.util.Hashtable;
 import javax.sql.DataSource;
 import javax.naming.InitialContext;
 
-import org.apache.velocity.runtime.Runtime;
-import org.apache.velocity.runtime.resource.Resource;
+import org.apache.flex.forks.velocity.runtime.Runtime;
+import org.apache.flex.forks.velocity.runtime.resource.Resource;
 
-import org.apache.velocity.exception.ResourceNotFoundException;
+import org.apache.flex.forks.velocity.exception.ResourceNotFoundException;
 
 import org.apache.commons.collections.ExtendedProperties;
 import java.sql.Connection;
@@ -50,7 +50,7 @@ import java.sql.SQLException;
  * <br>
  * ds.resource.loader.public.name = DataSource <br>
  * ds.resource.loader.description = Velocity DataSource Resource Loader <br>
- * ds.resource.loader.class = org.apache.velocity.runtime.resource.loader.DataSourceResourceLoader <br>
+ * ds.resource.loader.class = org.apache.flex.forks.velocity.runtime.resource.loader.DataSourceResourceLoader <br>
  * ds.resource.loader.resource.datasource = java:comp/env/jdbc/Velocity <br>
  * ds.resource.loader.resource.table = tb_velocity_template <br>
  * ds.resource.loader.resource.keycolumn = id_template <br>

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/loader/FileResourceLoader.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/loader/FileResourceLoader.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/loader/FileResourceLoader.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/loader/FileResourceLoader.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.resource.loader;
+package org.apache.flex.forks.velocity.runtime.resource.loader;
 
 /*
  * Copyright 2001,2004 The Apache Software Foundation.
@@ -25,11 +25,11 @@ import java.io.FileNotFoundException;
 import java.util.Hashtable;
 import java.util.Vector;
 
-import org.apache.velocity.util.StringUtils;
+import org.apache.flex.forks.velocity.util.StringUtils;
 
-import org.apache.velocity.runtime.resource.Resource;
+import org.apache.flex.forks.velocity.runtime.resource.Resource;
 
-import org.apache.velocity.exception.ResourceNotFoundException;
+import org.apache.flex.forks.velocity.exception.ResourceNotFoundException;
 
 import org.apache.commons.collections.ExtendedProperties;
 

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/loader/JarHolder.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/loader/JarHolder.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/loader/JarHolder.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/loader/JarHolder.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.resource.loader;
+package org.apache.flex.forks.velocity.runtime.resource.loader;
 
 /*
  * Copyright 2001,2004 The Apache Software Foundation.
@@ -24,9 +24,9 @@ import java.util.jar.JarEntry;
 import java.util.jar.JarFile;
 import java.util.Hashtable;
 
-import org.apache.velocity.runtime.RuntimeServices;
+import org.apache.flex.forks.velocity.runtime.RuntimeServices;
 
-import org.apache.velocity.exception.ResourceNotFoundException;
+import org.apache.flex.forks.velocity.exception.ResourceNotFoundException;
 
 /**
  * A small wrapper around a Jar

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/loader/JarResourceLoader.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/loader/JarResourceLoader.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/loader/JarResourceLoader.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/loader/JarResourceLoader.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.resource.loader;
+package org.apache.flex.forks.velocity.runtime.resource.loader;
 
 /*
  * Copyright 2001,2004 The Apache Software Foundation.
@@ -21,9 +21,9 @@ import java.io.InputStream;
 import java.util.Hashtable;
 import java.util.Vector;
 
-import org.apache.velocity.util.StringUtils;
-import org.apache.velocity.runtime.resource.Resource;
-import org.apache.velocity.exception.ResourceNotFoundException;
+import org.apache.flex.forks.velocity.util.StringUtils;
+import org.apache.flex.forks.velocity.runtime.resource.Resource;
+import org.apache.flex.forks.velocity.exception.ResourceNotFoundException;
 import org.apache.commons.collections.ExtendedProperties;
 
 /**
@@ -36,7 +36,7 @@ import org.apache.commons.collections.Ex
  * </p>
  * <p><pre>
  *    resource.loader = jar
- *    jar.resource.loader.class = org.apache.velocity.runtime.resource.loader.JarResourceLoader
+ *    jar.resource.loader.class = org.apache.flex.forks.velocity.runtime.resource.loader.JarResourceLoader
  *    jar.resource.loader.path = list of JAR &lt;URL&gt;s
  * </pre></p>
  *
@@ -50,7 +50,7 @@ import org.apache.commons.collections.Ex
  * </p>
  *
  * <p> For a working example, see the unit test case, 
- *  org.apache.velocity.test.MultiLoaderTestCase class
+ *  org.apache.flex.forks.velocity.test.MultiLoaderTestCase class
  * </p>
  * 
  * @author <a href="mailto:daveb@miceda-data.com">Dave Bryson</a>

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/loader/ResourceLoader.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/loader/ResourceLoader.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/loader/ResourceLoader.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/loader/ResourceLoader.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.resource.loader;
+package org.apache.flex.forks.velocity.runtime.resource.loader;
 
 /*
  * Copyright 2001,2004 The Apache Software Foundation.
@@ -18,11 +18,11 @@ package org.apache.velocity.runtime.reso
 
 import java.io.InputStream;
 
-import org.apache.velocity.runtime.RuntimeServices;
+import org.apache.flex.forks.velocity.runtime.RuntimeServices;
 
-import org.apache.velocity.runtime.resource.Resource;
+import org.apache.flex.forks.velocity.runtime.resource.Resource;
 
-import org.apache.velocity.exception.ResourceNotFoundException;
+import org.apache.flex.forks.velocity.exception.ResourceNotFoundException;
 
 import org.apache.commons.collections.ExtendedProperties;
 

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/loader/ResourceLoaderFactory.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/loader/ResourceLoaderFactory.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/loader/ResourceLoaderFactory.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/loader/ResourceLoaderFactory.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.resource.loader;
+package org.apache.flex.forks.velocity.runtime.resource.loader;
 
 /*
  * Copyright 2001,2004 The Apache Software Foundation.
@@ -16,8 +16,8 @@ package org.apache.velocity.runtime.reso
  * limitations under the License.
  */
 
-import org.apache.velocity.runtime.RuntimeServices;
-import org.apache.velocity.util.StringUtils;
+import org.apache.flex.forks.velocity.runtime.RuntimeServices;
+import org.apache.flex.forks.velocity.util.StringUtils;
 
 /**
  * Factory to grab a template loader.

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/visitor/BaseVisitor.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/visitor/BaseVisitor.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/visitor/BaseVisitor.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/visitor/BaseVisitor.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.visitor;
+package org.apache.flex.forks.velocity.runtime.visitor;
 
 /*
  * Copyright 2000-2001,2004 The Apache Software Foundation.
@@ -18,9 +18,9 @@ package org.apache.velocity.runtime.visi
 
 import java.io.Writer;
 
-import org.apache.velocity.context.InternalContextAdapter;
+import org.apache.flex.forks.velocity.context.InternalContextAdapter;
 
-import org.apache.velocity.runtime.parser.node.*;
+import org.apache.flex.forks.velocity.runtime.parser.node.*;
 
 /**
  * This is the base class for all visitors.
--- incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/Resource.java (original)
+++ incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/Resource.java Tue May 29 17:10:53 2012
@@ -1,4 +1,4 @@
-package org.apache.velocity.runtime.resource;
+package org.apache.flex.forks.velocity.runtime.resource;
 
 /*
  * Copyright 2001,2004 The Apache Software Foundation.
@@ -16,13 +16,13 @@ package org.apache.velocity.runtime.reso
  * limitations under the License.
  */
 
-import org.apache.velocity.runtime.RuntimeServices;
-import org.apache.velocity.runtime.RuntimeConstants;
+import org.apache.flex.forks.velocity.runtime.RuntimeServices;
+import org.apache.flex.forks.velocity.runtime.RuntimeConstants;
 
-import org.apache.velocity.runtime.resource.loader.ResourceLoader;
+import org.apache.flex.forks.velocity.runtime.resource.loader.ResourceLoader;
 
-import org.apache.velocity.exception.ResourceNotFoundException;
-import org.apache.velocity.exception.ParseErrorException;
+import org.apache.flex.forks.velocity.exception.ResourceNotFoundException;
+import org.apache.flex.forks.velocity.exception.ParseErrorException;
 
 /**
  * This class represent a general text resource that
@@ -100,8 +100,8 @@ public abstract class Resource
      * performed.
      *
      * @return Whether the resource could be processed successfully.
      * For a {@link org.apache.velocity.Template} or {@link
      * org.apache.velocity.runtime.resource.ContentResource}, this
      * indicates whether the resource could be read.
      * @exception ResourceNotFoundException Similar in semantics as
      * returning <code>false</code>.
@@ -100,8 +100,8 @@ public abstract class Resource
      *
      * @return Whether the resource could be processed successfully.
-     * For a {@link org.apache.velocity.Template} or {@link
-     * org.apache.velocity.runtime.resource.ContentResource}, this
+     * For a {@link org.apache.flex.forks.velocity.Template} or {@link
+     * org.apache.flex.forks.velocity.runtime.resource.ContentResource}, this
      * indicates whether the resource could be read.
      * @exception ResourceNotFoundException Similar in semantics as

Modified: incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/ResourceCache.java
URL: http://svn.apache.org/viewvc/incubator/flex/trunk/modules/thirdparty/velocity/src/java/org/apache/flex/forks/velocity/runtime/resource/ResourceCache.java?rev=1343856&r1=1343785&r2=1343856&view=diff
==============================================================================